"""{{app}} URL Configuration

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/{{django_version}}/topics/http/urls/
"""
from django.conf.urls import url
from django.contrib import admin
from {{app}}.utils.urls import load_urls

urlpatterns = [
    url(r'^admin/', admin.site.urls),
] + load_urls(__file__, namespaced=False)
